@@ -192,7 +192,7 @@ class R3sponse(object):
 			#print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
 			if json:
 				if response != {}:
-					print(response)
+					print(response.json())
 				elif error != None:
 					print(self.error_response(error))
 				else:
@@ -252,10 +252,29 @@ class R3sponse(object):
 
 	# a response object.
 	def serialize(self, response={}):
+		if isinstance(response, str):
+			try:
+				response = ast.literal_eval(response)
+			except:
+				response = json.loads(response)
 		for key in list(response.keys()):
 			value = response[key]
-			if isinstance(value, dict):
-				value = self.serialize(value)
+			no_dict = False
+			try:
+				if isinstance(value, dict):
+					value = self.serialize(value)
+				else:
+					try:
+						value = ast.literal_eval(value)
+						value = self.serialize(value)
+					except:
+						try:
+							value = json.loads(value)
+							value = self.serialize(value)
+						except:
+							no_dict = True
+			except: a=1
+			if no_dict == False: a=1
 			elif value in [True, "True", "true", "TRUE"]: value = True
 			elif value in [False, "False", "false", "FALSE"]: value = False
 			elif isinstance(value, str):
@@ -263,10 +282,8 @@ class R3sponse(object):
 					try: value = float(value)
 					except: a=1
 				else:
-					try: value = ast.literal_eval(value)
-					except:
-						try: value = int(value)
-						except: a=1
+					try: value = int(value)
+					except: a=1
 			response[key] = value
 		return response
 	def response(self, response={
